==> mythplugins-0.18.1.tar.bz2: mythplugins-0.18.1/mythgallery/i18n/mythgallery_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation>Verzeichnis: </translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Erzeugt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Geändert: </translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelanzahl</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>Megapixel</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Drehung</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>°</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Bilder importieren?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Nichts Neues gefunden</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>OpenGL-Unterstützung nicht verfügbar</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>90° drehen</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>270° drehen</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Zufall</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Verzeichnis mit Bildern</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Dieses Verzeichnis muß existieren und MythGallery Leserechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Verzeichnisse für den Bildimport</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Art des Übergangs</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Art des Hintergrunds</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Jedes Bild wird für diese Anzahl Sekunden angezeigt.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>MythGallery Einstellungen</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Eine durch Kommas getrennte Liste von Verzeichnissen. Ist das Element in der Liste ein Verzeichnis, wird sein Inhalt kopiert. Ist es eine ausführbare Datei wird diese gestartet.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Wählt die Art des Übergangs zwischen zwei Bildern im Diashow Modus.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Die Art des Hintergrunds für Bilder in der Einzelanzeige.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Anzeigedauer im Diashow-Modus</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Nutze OpenGL-Übergänge</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Aktiviert auf OpenGL basierende Übergänge für den Diashow-Modus.</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Art des OpenGL-Übergangs</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Bestimmt welcher OpenGL-Übergang im Diashow-Modus verwendet wird.</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Bilderverzeichnis existiert nicht oder ist nicht lesbar.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation>Befehl zum Abspielen von Filmen</translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation>Dieser Befehl wird ausgeführt, wenn ein Film ausgewählt wird</translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelanzahl</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Drehung</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>Megapixel</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>°</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Erzeugt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Geändert: </translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation>Verzeichnis: </translation>
    </message>
</context>
</TS>

==> mythplugins-0.19.tar.bz2: mythplugins-0.19/mythgallery/i18n/mythgallery_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation>Verzeichnis: </translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Erzeugt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Geändert: </translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelanzahl</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>Megapixel</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Drehung</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>°</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Bilder importieren?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Nichts Neues gefunden</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>OpenGL-Unterstützung nicht verfügbar</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>90° drehen</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>270° drehen</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Zufall</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Verzeichnis mit Bildern</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Dieses Verzeichnis muß existieren und MythGallery Leserechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Verzeichnisse für den Bildimport</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Art des Übergangs</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Art des Hintergrunds</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Jedes Bild wird für diese Anzahl Sekunden angezeigt.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>MythGallery Einstellungen</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Eine durch Kommas getrennte Liste von Verzeichnissen. Ist das Element in der Liste ein Verzeichnis, wird sein Inhalt kopiert. Ist es eine ausführbare Datei wird diese gestartet.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Wählt die Art des Übergangs zwischen zwei Bildern im Diashow Modus.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Die Art des Hintergrunds für Bilder in der Einzelanzeige.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Anzeigedauer im Diashow-Modus</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Nutze OpenGL-Übergänge</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Aktiviert auf OpenGL basierende Übergänge für den Diashow-Modus.</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Art des OpenGL-Übergangs</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Bestimmt welcher OpenGL-Übergang im Diashow-Modus verwendet wird.</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Bilderverzeichnis existiert nicht oder ist nicht lesbar.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation>Befehl zum Abspielen von Filmen</translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation>Dieser Befehl wird ausgeführt, wenn ein Film ausgewählt wird.</translation>
    </message>
    <message>
        <source>Store thumbnails in image directory</source>
        <translation>Vorschaubilder im Bilderverzeichnis speichern</translation>
    </message>
    <message>
        <source>If set, thumbnails are stored in &apos;.thumbcache&apos; directories within the above directory. If cleared, they are stored in your home directory.</source>
        <translation>Falls gesetzt, werden Vorschaubilder im &apos;.thumbcache&apos;-Verzeichnis innerhalb des o.g. Pfades gespeichert. Falls nicht gesetzt, werden sie in Ihrem home-Verzeichnis gespeichert.</translation>
    </message>
    <message>
        <source>Recurse into directories</source>
        <translation>Rekursiv in Verzeichnisse absteigen</translation>
    </message>
    <message>
        <source>Check this to let the slideshow recurse into sub-directories.</source>
        <translation>Anklicken damit in der Diashow auch Bilder in Unterverzeichnissen angezeigt werden.</translation>
    </message>
    <message>
        <source>Overlay caption</source>
        <translation>Titel einblenden</translation>
    </message>
    <message>
        <source>This is the number of seconds to show a caption on top of a full size picture.</source>
        <translation>Dauer in Sekunden zum Anzeigen des Titels auf dem Vollbild-Photo.</translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelanzahl</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Drehung</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>Megapixel</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>°</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Erzeugt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Geändert: </translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation>Verzeichnis: </translation>
    </message>
</context>
</TS>
